@@ -3,7 +3,7 @@
 
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
-# $Id: smsconEditorMain.py 132 2011-12-30 14:56:06Z saturn $
+# $Id: smsconEditorMain.py 136 2012-01-02 19:40:38Z saturn $
 ##############################################################
 # Copyright (c) 2010-2011 Christos Zamantzas
 # Licenced under GPLv2
@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.9.10-1'
+Version = '0.9.11-1'
 
 import os
 import sys
@@ -55,6 +55,7 @@ from smsconEditorSSHUI import *
 from smsconEditorHostUI import *
 from smsconEditorInitUI import *
 from smsconEditorTestUI import *
+from smsconEditorLogUI import *
 
 ##############################################################
 
@@ -344,6 +345,7 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        QtCore.QObject.connect(self.ui.pushButtonHost,     QtCore.SIGNAL('clicked()'), self.doHost)
        QtCore.QObject.connect(self.ui.pushButtonInit,     QtCore.SIGNAL('clicked()'), self.doInit)
        QtCore.QObject.connect(self.ui.pushButtonTest,     QtCore.SIGNAL('clicked()'), self.doTest)
+       QtCore.QObject.connect(self.ui.pushButtonLog,      QtCore.SIGNAL('clicked()'), self.doReadLog)
        QtCore.QObject.connect(self.ui.pushButtonAbout,    QtCore.SIGNAL('clicked()'), self.doAbout)
        QtCore.QObject.connect(self.ui.pushButtonNewPass,  QtCore.SIGNAL('clicked()'), self.doUpdatePassword)
         
@@ -437,6 +439,9 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        
     def doTest(self):
        self.testWin = smsconEditorTest(self)
+
+    def doReadLog(self):
+       self.logWin = smsconEditorLog(self)
        
     def doUpdatePassword(self):
        ##Open Dialog - change password
@@ -579,7 +584,7 @@ class smsconEditorGeneral(QtGui.QMainWindow):  ## General Settings
                       'If numbers differ, SMS notifications will be send to both.'
        EditConfigAndApply(newConf, message)
 
-class smsconEditorEmail(QtGui.QMainWindow):    ## Email Settings 
+class smsconEditorEmail(QtGui.QMainWindow):        ## Email Settings 
 
     def __init__(self, parent=None):
 
@@ -627,7 +632,7 @@ class smsconEditorEmail(QtGui.QMainWindow):    ## Email Settings
                          '\nMail server: %s - Port: %s' % (newConf["MAILSERVER"], newConf["MAILPORT"])
         EditConfigAndApply(newConf, message)
         
-class smsconEditorCommands(QtGui.QMainWindow): ## Commands Renaming
+class smsconEditorCommands(QtGui.QMainWindow):     ## Commands Renaming
 
     def __init__(self, parent=None):
 
@@ -734,7 +739,7 @@ class smsconEditorCommands(QtGui.QMainWindow): ## Commands Renaming
                       '\nCommon suffix: %s' % newConf['SMS_COMSUFFIX']
        EditConfigAndApply(newConf, message)
       
-class smsconEditorSSH(QtGui.QMainWindow):      ## SSH Settings
+class smsconEditorSSH(QtGui.QMainWindow):          ## SSH Settings
 
     def __init__(self, parent=None):
 
@@ -783,7 +788,7 @@ class smsconEditorSSH(QtGui.QMainWindow):      ## SSH Settings
                       '\nForwarded Port: %s'             % (newConf["REMOTE2LOCALPORT"])
        EditConfigAndApply(newConf, message)
 
-class smsconEditorHost(QtGui.QMainWindow):     ## Host Settings
+class smsconEditorHost(QtGui.QMainWindow):         ## Host Settings
 
     def __init__(self, parent=None):
 
@@ -824,7 +829,7 @@ class smsconEditorHost(QtGui.QMainWindow):     ## Host Settings
                       '\nCheck interval: %s'  % newConf["CHECKTIME"]
        EditConfigAndApply(newConf, message)
 
-class smsconEditorTest(QtGui.QMainWindow):     ## Testing of main functions for settings correctness.
+class smsconEditorTest(QtGui.QMainWindow):         ## Testing of main functions for settings correctness.
 
     def __init__(self, parent=None):
 
@@ -884,6 +889,22 @@ class smsconEditorTest(QtGui.QMainWindow):     ## Testing of main functions for
 
     def doSendTestScript(self):
        self.smsconTest('-test script', 'The script execution has been invoked.')
+
+class smsconEditorLog(QtGui.QMainWindow):          ## Log Reader
+
+    def __init__(self, parent=None):
+
+       ##Build parent user interface
+       QtGui.QWidget.__init__(self, parent)
+       self.ui = Ui_smsconEditorLogUI()
+       self.ui.setupUi(self)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+       self.show()       
+
+       storedLog = os.popen('sudo smscon -pw %s -log | tail -n 500' % editConf['MASTERNUMBER']).read()
+       self.ui.textBrowserLog.setText(storedLog)
+       self.ui.textBrowserLog.moveCursor(QtGui.QTextCursor.End)
       
 class smsconEditorPasswordChange(QtGui.QDialog):
 
